projecttype

package
v0.5.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 22, 2026 License: MIT Imports: 0 Imported by: 0

Documentation

Overview

Package projecttype defines types for detected project frameworks and languages.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AspireProject

type AspireProject struct {
	Dir         string
	ProjectFile string // Path to AppHost.csproj
}

AspireProject represents a detected Aspire project.

type DotnetProject

type DotnetProject struct {
	Path string // Path to .csproj or .sln file
}

DotnetProject represents a detected .NET project.

type FunctionAppProject

type FunctionAppProject struct {
	Dir      string // Directory containing host.json
	Variant  string // Type of Functions app: "logicapps", "nodejs", "python", "dotnet", "java"
	Language string // Programming language detected for the project
}

FunctionAppProject represents a detected Azure Functions project.

type LogicAppProject

type LogicAppProject struct {
	Dir string // Directory containing workflows folder
}

LogicAppProject represents a detected Logic Apps Standard project.

type NodeProject

type NodeProject struct {
	Dir             string
	PackageManager  string // "npm", "pnpm", or "yarn"
	IsWorkspaceRoot bool   // True if this project defines npm/yarn/pnpm workspaces
	WorkspaceRoot   string // Path to the workspace root if this is a workspace child
}

NodeProject represents a detected Node.js project.

type PythonProject

type PythonProject struct {
	Dir            string
	PackageManager string // "uv", "poetry", or "pip"
	Entrypoint     string // Optional: entry point file specified in azure.yaml
}

PythonProject represents a detected Python project.

Jump to