Documentation
¶
Overview ¶
Package projecttype defines types for detected project frameworks and languages.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AspireProject ¶
AspireProject represents a detected Aspire project.
type DotnetProject ¶
type DotnetProject struct {
Path string // Path to .csproj or .sln file
}
DotnetProject represents a detected .NET project.
type FunctionAppProject ¶
type FunctionAppProject struct {
Dir string // Directory containing host.json
Variant string // Type of Functions app: "logicapps", "nodejs", "python", "dotnet", "java"
Language string // Programming language detected for the project
}
FunctionAppProject represents a detected Azure Functions project.
type LogicAppProject ¶
type LogicAppProject struct {
Dir string // Directory containing workflows folder
}
LogicAppProject represents a detected Logic Apps Standard project.
type NodeProject ¶
type NodeProject struct {
Dir string
PackageManager string // "npm", "pnpm", or "yarn"
IsWorkspaceRoot bool // True if this project defines npm/yarn/pnpm workspaces
WorkspaceRoot string // Path to the workspace root if this is a workspace child
}
NodeProject represents a detected Node.js project.
type PythonProject ¶
type PythonProject struct {
Dir string
PackageManager string // "uv", "poetry", or "pip"
Entrypoint string // Optional: entry point file specified in azure.yaml
}
PythonProject represents a detected Python project.
Click to show internal directories.
Click to hide internal directories.